@@ -294,6 +294,9 @@ Client::Client(bool minimized, QObject *parent) : QObject(parent)
     connect(mainWin, SIGNAL(removeGroupParticipant(QString,QString)),
             this,SLOT(sendRemoveGroupParticipant(QString,QString)));
 
+    connect(mainWin, SIGNAL(promoteGroupParticipant(QString,QString)),
+            this,SLOT(sendPromoteGroupParticipant(QString,QString)));
+
     connect(mainWin, SIGNAL(requestPrivacyList()),
             this, SLOT(requestPrivacyList()));
 
@@ -927,9 +930,7 @@ void Client::getMyStatus()
 void Client::changeStatus(QString newStatus)
 {
     settings->setValue(SETTINGS_STATUS,newStatus);
-    FMessage message("s.us",newStatus,"");
-    message.type = FMessage::BodyMessage;
-    queueMessage(message);
+    connection->sendSetStatus(newStatus);
 }
 
 void Client::changeUserName(QString newUserName)
@@ -1667,6 +1668,16 @@ void Client::sendRemoveGroupParticipant(QString gjid, QString jid)
     }
 }
 
+void Client::sendPromoteGroupParticipant(QString gjid, QString jid)
+{
+    if (connectionStatus == LoggedIn)
+    {
+        QStringList participants;
+        participants.append(jid);
+        connection->sendPromoteParticipants(gjid, participants);
+    }
+}
+
 void Client::requestPrivacyList()
 {
     if (connectionStatus == LoggedIn)
